#
# spec file for package libpano
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name libpano13

Name:           libpano
Version:        2.9.19
Release:        lp150.1.4
Summary:        Panorama Tools Back-End Library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            http://panotools.sourceforge.net/
Source:         %{_name}-%{version}.tar.bz2
# https://sourceforge.net/tracker/?func=detail&aid=2833227&group_id=96188&atid=613956
Patch0:         libpano-implicit-decl.patch
BuildRequires:  java-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Library and utilities for working with panoramas.

%package -n libpano13-3
Summary:        Panorama Tools Back-End Library
Group:          Development/Libraries/C and C++
Obsoletes:      %{name} < %{version}

%description -n libpano13-3
Library for working with panoramas.

%package utils
Summary:        Panorama Tools Utilities
Group:          Productivity/Graphics/Other
Obsoletes:      %{name} < %{version}
# Explicitly mentioned libpano (for <= 10.2) probably means libpano-utils:
Provides:       %{name} = %{version}

%description utils
Utilities for working with panoramas.

%package devel
Summary:        Panorama Tools Back-End Library - files mandatory for development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libpano13-3 = %{version}

%description devel
Development files for library for working with panoramas.

%prep
%setup -q -n %{_name}-%{version}
%patch0

%build
autoreconf -f -i
%configure\
	--with-java=%{java_home}
make %{?_smp_mflags}

%install
%make_install
#Axe Libs.private from .pc files, which do not behave as expected
sed -i -e '/^Libs.private/d' %{buildroot}%{_libdir}/pkgconfig/libpano13.pc
find %{buildroot} -type f -name "*.la" -print -delete

%clean
rm -rf %{buildroot}

%post -n libpano13-3 -p /sbin/ldconfig

%postun -n libpano13-3 -p /sbin/ldconfig

%files -n libpano13-3
%defattr(-,root,root)
%doc README README.linux AUTHORS COPYING NEWS ChangeLog ChangeLog.hg doc/*.txt tools/README.PTmender
%{_libdir}/libpano13.so.*

%files utils
%defattr(-,root,root)
%{_bindir}/*
%doc %{_mandir}/man?/*.*

%files devel
%defattr(-,root,root)
%{_includedir}/pano13
%{_libdir}/libpano13.so
%{_libdir}/pkgconfig/libpano13.pc

%changelog
* Mon Oct 13 2014 salsergey@gmail.com
- Upgraded to version 2.9.19
  * There are new Tpy and Tpr parameters
  * Added Hammer output projection
  * Updated PSD functions to write PSB (large file) format too
  * Various bugs have been fixed in these projections: triplane output,
  architectural output, orthographic output and Thoby input.
  * Other bugfixes
* Tue Jan 10 2012 crrodriguez@opensuse.org
- Add explicit BuildRequires on libjpeg-devel and zlib-devel
- libpano-devel should not require libtiff-devel, libjpeg-devel
  or libtiff-devel as they are not needed for building or linking.
  This may break packages with wrong buildrequires.
- Remove "la" files
- run spec cleaner
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue May 31 2011 sbrabec@suse.cz
- Upgraded to version 2.9.18:
  * fix build with libpng-1.5
  * minor fixes
* Wed Apr 27 2011 sbrabec@suse.cz
- Upgraded to version 2.9.17:
  * minor fixes and improvements
  * support for pkg-config
  * new soname
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Thu Aug  6 2009 sbrabec@suse.cz
- Updated to branch libpano13, version 2.9.14:
  * ABI has changed since 2.9.12, new soname
  * number of new input and output projections
  * new command-line tool
  * documentation, cleanups and bugfixes
* Mon Oct 13 2008 sbrabec@suse.cz
- Fixed implicit declarations, invalid use of write() and invalid
  format specification.
* Mon Sep  8 2008 sbrabec@suse.cz
- Updated to branch libpano13, version 2.9.12:
  * many new functions and improvements, see ChangeLog for more
  * new utility PTmender, replacement of binary-only PTStitcher
  * new branch does not support binary-only 1.2 applications
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 2.8.6:
  * Bug fixes.
- Split package according to shared library packaging policy.
* Wed Nov  8 2006 prusnak@suse.cz
- fixed subscript out of range [#204092]
* Thu Aug 17 2006 postadal@suse.cz
- updated to version 2.8.4
  * a lot of new lenstypes, panotypes, filters and fixes see ChangeLog
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 sbrabec@suse.cz
- Updated to version 2.7.0.14.
* Wed Jul 20 2005 nadvornik@suse.cz
- updated to 2.7.0.10
- added devel subpackage
- installed commandline tools
* Thu Apr 14 2005 mcihar@suse.cz
- update to 2.7.0.9
- fix compilation
* Sun Feb 27 2005 ro@suse.de
- next try to fix compilation
* Sun Feb 20 2005 ro@suse.de
- temporary workaround to fix build
* Tue Dec 21 2004 mcihar@suse.cz
- update to 2.7.0.8
* Mon Aug  9 2004 ro@suse.de
- java is still in /usr/lib even on lib64 platforms
* Fri Jul 30 2004 mcihar@suse.cz
- compile with -fPIC
* Fri Jul 30 2004 mcihar@suse.cz
- initial packaging
